// generated from rosidl_generator_c/resource/idl.h.em
// with input from visualization_msgs:msg/ImageMarker.idl
// generated code does not contain a copyright notice

#ifndef VISUALIZATION_MSGS__MSG__IMAGE_MARKER_H_
#define VISUALIZATION_MSGS__MSG__IMAGE_MARKER_H_

#include "visualization_msgs/msg/detail/image_marker__struct.h"
#include "visualization_msgs/msg/detail/image_marker__functions.h"
#include "visualization_msgs/msg/detail/image_marker__type_support.h"

#endif  // VISUALIZATION_MSGS__MSG__IMAGE_MARKER_H_
